@@ -223,8 +223,8 @@ class UnitAttribute(core.LiteralAttribute):
         else:
             return None
 
-    def get_excel_validation(self, sheet_models=None, doc_metadata_model=None):
-        """ Get Excel validation
+    def get_xlsx_validation(self, sheet_models=None, doc_metadata_model=None):
+        """ Get XLSX validation
 
         Args:
             sheet_models (:obj:`list` of :obj:`Model`, optional): models encoded as separate sheets
@@ -233,7 +233,7 @@ class UnitAttribute(core.LiteralAttribute):
         Returns:
             :obj:`wc_utils.workbook.io.FieldValidation`: validation
         """
-        validation = super(UnitAttribute, self).get_excel_validation(sheet_models=sheet_models,
+        validation = super(UnitAttribute, self).get_xlsx_validation(sheet_models=sheet_models,
                                                                      doc_metadata_model=doc_metadata_model)
 
         if self.choices is not None:
@@ -494,8 +494,8 @@ class QuantityAttribute(core.LiteralAttribute):
         else:
             return None
 
-    def get_excel_validation(self, sheet_models=None, doc_metadata_model=None):
-        """ Get Excel validation
+    def get_xlsx_validation(self, sheet_models=None, doc_metadata_model=None):
+        """ Get XLSX validation
 
         Args:
             sheet_models (:obj:`list` of :obj:`Model`, optional): models encoded as separate sheets
@@ -504,7 +504,7 @@ class QuantityAttribute(core.LiteralAttribute):
         Returns:
             :obj:`wc_utils.workbook.io.FieldValidation`: validation
         """
-        validation = super(QuantityAttribute, self).get_excel_validation(sheet_models=sheet_models,
+        validation = super(QuantityAttribute, self).get_xlsx_validation(sheet_models=sheet_models,
                                                                          doc_metadata_model=doc_metadata_model)
 
         validation.ignore_blank = self.none
